@@ -1,22 +1,32 @@
 /*
     device.h -- generic header for device.c
-    Copyright (C) 2003-2005 Marc Lehmann <gvpe@schmorp.de>
+    Copyright (C) 2003-2008 Marc Lehmann <gvpe@schmorp.de>
  
     This file is part of GVPE.
 
-    GVPE is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
- 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
- 
-    You should have received a copy of the GNU General Public License
-    along with gvpe; if not, write to the Free Software
-    Foundation, Inc. 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    GVPE is free software; you can redistribute it and/or modify it
+    under the terms of the GNU General Public License as published by the
+    Free Software Foundation; either version 3 of the License, or (at your
+    option) any later version.
+   
+    This program is distributed in the hope that it will be useful, but
+    WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
+    Public License for more details.
+   
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, see <http://www.gnu.org/licenses/>.
+   
+    Additional permission under GNU GPL version 3 section 7
+   
+    If you modify this Program, or any covered work, by linking or
+    combining it with the OpenSSL project's OpenSSL library (or a modified
+    version of that library), containing parts covered by the terms of the
+    OpenSSL or SSLeay licenses, the licensors of this Program grant you
+    additional permission to convey the resulting work.  Corresponding
+    Source for a non-source form of such a combination shall include the
+    source code for the parts of OpenSSL used as well as that of the
+    covered work.
 */
 
 #ifndef GVPE_DEVICE_H__
@@ -29,7 +39,8 @@
 #include "global.h"
 #include "util.h"
 
-struct net_packet {
+struct net_packet
+{
   u32 len; // actually u16, but padding...
 
   u8 &operator[] (u16 offset) const;
@@ -81,7 +92,8 @@ struct net_packet {
   void operator delete (void *p);
 };
 
-struct data_packet : net_packet {
+struct data_packet : net_packet
+{
   u8 data_[MAXSIZE];
 };
 
@@ -97,13 +109,15 @@ u8 *net_packet::at (u16 offset) const
   return &((*this)[offset]);
 }
 
-struct tap_packet : net_packet {
+struct tap_packet : net_packet
+{
   mac dst;
   mac src;
   u8 data[MAXSIZE - 12];
 };
 
-struct tap_device {
+struct tap_device
+{
   int fd;
 
   // network interface name or identifier
